#
# spec file for package knock
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           knock
Version:        0.8
Release:        4.3
Summary:        A Port-Knocking Client
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Security
URL:            http://www.zeroflux.org/knock/
Source0:        http://www.zeroflux.org/proj/knock/files/%{name}-%{version}.tar.gz
Source1:        %{name}d.sysconfig
Source2:        %{name}d.init
Source3:        %{name}d.conf
Source4:        %{name}d.service
BuildRequires:  libpcap-devel
BuildRequires:  systemd-rpm-macros

%description
The server part (package knockd) listens to all traffic on an ethernet
(or PPP) interface, looking for special "knock" sequences of port hits.
This client makes these port hits by sending a TCP (or UDP) packet to a
port on the server. This port does not need to be open. Since knockd
listens at the link-layer level, it sees all traffic even if it is
destined for a closed port. When the server detects a specific sequence
of port hits, it runs a command defined in its configuration file. This
can be used to open up holes in a firewall for quick access.

%package -n knockd
Summary:        A port-knocking server
Group:          Productivity/Networking/Security
%{?systemd_requires}

%description -n knockd
It listens to all traffic on an ethernet (or PPP) interface, looking
for special "knock" sequences of port-hits. A client (package knock)
makes these port-hits by sending a TCP (or UDP) packet to a port on the
server. This port need not be open -- since knockd listens at the
link-layer level, it sees all traffic even if it's destined for a
closed port. When the server detects a specific sequence of port-hits,
it runs a command defined in its configuration file. This can be used
to open up holes in a firewall for quick access.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
sed -i -e "s:iptables:%{_sbindir}/iptables:" %{SOURCE3}
install -m 600 -D %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}d.conf
install -D -m 644 %{SOURCE4} %{buildroot}/%{_unitdir}/%{name}d.service
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}d
rm -rf %{buildroot}%{_datadir}/doc

%pre -n knockd
%service_add_pre %{name}d.service

%post -n knockd
%service_add_post %{name}d.service

%preun -n knockd
%service_del_preun %{name}d.service

%postun -n knockd
%service_del_postun %{name}d.service

%files
%defattr(-,root,root)
%attr(0755,root,root) %{_bindir}/%{name}
%{_mandir}/man?/%{name}.*
%{_sbindir}/knock_helper_ipt.sh

%files -n knockd
%defattr(-,root,root)
%doc README.md ChangeLog TODO
%license COPYING
%{_sbindir}/%{name}d
%{_unitdir}/%{name}d.service
%{_sbindir}/rc%{name}d
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}d.conf
%{_mandir}/man?/%{name}d.*

%changelog
* Mon Jan 20 2025 Daniel Donisa <daniel.donisa@suse.com>
- Update copyright year
* Mon Jan 13 2025 Daniel Donisa <daniel.donisa@suse.com>
- Remove conditionals around systemd as all versions use systemd now.
* Tue Sep 28 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * knockd.service
* Wed May 19 2021 Daniel Donisa <daniel.donisa@suse.com>
- Update to version 0.8
  * Multiple fixes (#67, #77)
  * IPv6 support (Sebastien Valat)
- dropped knock-0.5.patch, knock-include.patch
* Wed Jul 10 2019 brassh@web.de
- fix uninitialized tcpflags variables in knockd.c
  (Bug#1138376: Knockd unable to start after upgrade to LEAP 15.1)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Tue Dec  1 2015 p.drouand@gmail.com
- Update to version 0.7
  * Document the 'target' configuration directive.
  * Merging OS-specific networking code to reduce LOCs and the
    sea of #ifdefs.
  * Added 50ms timeout to pcap_open_live() to reduce CPU usage
    on network-heavy hosts. Pcap recommends we not use zero.
- Changes from version 0.6
  * Cleanup: Don't null-check before free
  * Cleanup: Consolidate flag-check logic
  * Accept single-knock sequences
  * Introduce a 'target' configuration directive, enabling knockd to
    react to connect attempts to a target host. Useful in cases where
    knockd is on a router and you want to send a target a wakeup packet.
- Add systemd support for openSUSE > 12.1
- Update knock-include.patch > knock-0.5-include.patch
- Remove obsolete AUTHORS section
- Use download Url as source
- Perform a spec-cleaner
* Mon Jun 15 2009 aj@suse.de
- Add knock-0.5-include.patch to fix build failure.
* Thu Jul 26 2007 prusnak@suse.cz
- changed libpcap to libpcap-devel in BuildRequires
* Tue Nov 14 2006 mskibbe@suse.de
- fix bug #220355 (iptables call is wrong)
* Wed Oct  4 2006 mskibbe@suse.de
- fix bug in iptables call
* Mon Sep 25 2006 mskibbe@suse.de
- fix iptables call in config
* Fri Sep 22 2006 mskibbe@suse.de
- fix sysconfig file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jun 30 2005 hvogel@suse.de
- Initial Package, Version 0.5
